--[[----------------------------------------------------------------------------
Copyright (c) 2012, Danny Fritz <dannyfritz@gmail.com>
Free Attribution License (FAL) 1.0
--]]----------------------------------------------------------------------------

--REQUIRES----------------------------------------------------------------------
local HC = require 'lib.HardonCollider'
--local player = require 'lib'

--VARIABLES---------------------------------------------------------------------
local Game = GameState:addState('Game')
love.graphics.setDefaultImageFilter('linear', 'nearest')
love.audio.setDistanceModel("exponent")
love.audio.setPosition(0,0,0)
love.audio.setOrientation(0,0,1, 0,1,0)
local image
local canvas = love.graphics.newCanvas()
love.graphics.setFont(love.graphics.newFont(64))
local microtimer = 0

local music = love.audio.newSource('snd/240 Big Blue.mp3')
music:setLooping(true)
music:setVolume(0.25)

local timer = {}
timer.time = 9
timer.finished = false
timer.update = function(self, dt)
	if not self.finished then
		self.time = self.time - dt
		music:setPosition(0,0, self.time/9)
		music:setVelocity(0, 0, 9/self.time)
	end
	if self.time <= 0 then
		self.finished = true
	end
end
timer.draw = function(self)
	if timer.finished then
		local float_factor = math.cos(microtimer*8)*200
		love.graphics.print("YOU WIN!", 60, 300 + float_factor)
		return
	end
	love.graphics.print(math.floor(self.time), 200, 600/timer.time)
end

local vanishing_effect = love.graphics.newPixelEffect('shader/vanishing-point.glsl')

local track = {}
track.distance = 0
track.y = 0
track.image = love.graphics.newImage('img/track.png')
track.update = function(self, dt)
	self.distance = self.distance + dt*768
	self.y = self.y + dt*768
	self.y = self.y % 576
end
track.draw = function(self)
	love.graphics.draw(self.image, 10, math.floor(self.y - 576), 0, 2)
	love.graphics.draw(self.image, 10, math.floor(self.y), 0, 2)
	love.graphics.draw(self.image, 10, math.floor(self.y + 576), 0, 2)
end


local player = {}
player.x = 200
player.y = 580
player.shadow = love.graphics.newImage('img/shadow.png')
player.image = love.graphics.newImage('img/fzero_bluefalcon_sheet.png')
local grid = Anim8.newGrid(50, 50, 400, 50)
player.anim = Anim8.newAnimation('loop', grid("5,1"), 1, {1})
player.update = function(self, dt)
	if love.keyboard.isDown('left', 'a') then
		self.x = self.x - 100*dt
	end
	if love.keyboard.isDown('right', 'd') then
		self.x = self.x + 100*dt
	end
	player.anim:update(dt)
end
player.draw = function(self)
	local x, y = math.floor(self.x), math.floor(self.y)
	love.graphics.draw(self.shadow, x, y+20)
	local float_factor = math.cos(microtimer*6)*3
	self.anim:draw(self.image, x, y + float_factor)
end



--------------------------------------------------------------------------------
function Game:enteredState()
	music:play()
end

--------------------------------------------------------------------------------
function Game:pausedState()
end

--------------------------------------------------------------------------------
function Game:continuedState()
end

--------------------------------------------------------------------------------
function Game:exitedState()
end

--------------------------------------------------------------------------------
function Game:update(dt)
	microtimer = microtimer + dt
	player:update(dt)
	track:update(dt)
	timer:update(dt)
end

--------------------------------------------------------------------------------
function Game:draw()
	self:drawGame();
end

--------------------------------------------------------------------------------
function Game:drawGame()
	love.graphics.setPixelEffect()
	love.graphics.setCanvas(canvas)
	track:draw()
	timer:draw()
	love.graphics.setCanvas()
	love.graphics.setPixelEffect(vanishing_effect)
	love.graphics.draw(canvas, 0, 0)
	love.graphics.setPixelEffect()
	player:draw()
end

--------------------------------------------------------------------------------
function Game:keypressed(key)
	if key == 'escape' then
		love.event.quit()
	end
end
